==> arla_0.36.2.orig.tar.gz: arla-0.36.2/nnpfs/bsd/bin/umount_nnpfs.c <==
/*
 * Copyright (c) 1995, 1996, 1997, 1998 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "mount_locl.h"

#ifdef RCSID
RCSID("$Id: umount_nnpfs.c,v 1.8 2002/09/17 18:54:53 lha Exp $");
#endif

static void
usage(const char *progname)
{
    fprintf(stderr, "Usage: %s [-f] path\n", "unmount_nnpfs");
    exit(1);
}

int
main(int argc, char **argv)
{
    int force = 0;
    char *name;

    name = strrchr(argv[0], '/');
    if (name)
	name++;
    else
	name = argv[0];

    if (argc != 2 && argc != 3)
	usage(name);

    if (strcmp(argv[1], "-f") == 0) {
	force = 1;
	if (argc != 3)
	    usage(name);
    }
    if (argv[1 + force][0] == '-')
	usage(name);

    if (unmount(argv[1 + force], (force ? 0 : MNT_FORCE)) != 0)
	perror("unmount");

    return 0;
}

==> arla-0.43.tar.gz: arla-0.43/nnpfs/bsd/bin/umount_nnpfs.c <==
/*
 * Copyright (c) 1995-1998, 2006 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "mount_locl.h"

#ifdef RCSID
RCSID("$Id: umount_nnpfs.c,v 1.9 2006/01/03 11:18:04 tol Exp $");
#endif

static void
usage(const char *progname)
{
    fprintf(stderr, "Usage: %s [-f] path\n", progname);
    exit(1);
}

int
main(int argc, char **argv)
{
    int force = 0;
    int flags = 0;
    char *name;

#ifdef __APPLE__
    flags |= MNT_FORCE;
#endif

    name = strrchr(argv[0], '/');
    if (name)
	name++;
    else
	name = argv[0];

    if (argc != 2 && argc != 3)
	usage(name);

    if (strcmp(argv[1], "-f") == 0) {
	force = 1;
	flags |= MNT_FORCE;
	if (argc != 3)
	    usage(name);
    }
    if (argv[1 + force][0] == '-')
	usage(name);

    if (unmount(argv[1 + force], flags) != 0)
	perror("unmount");

    return 0;
}
